@@ -1,4 +1,4 @@
-dd_KI_loglik_choosepar = function(trparsopt,trparsfix,idparsopt,idparsfix,idparsnoshift,pars2,brtsM,brtsS,missnumspec)
+dd_KI_loglik_choosepar = function(trparsopt,trparsfix,idparsopt,idparsfix,idparsnoshift,pars2,brtsM,brtsS,missnumspec,methode)
 {
    trpars1 = rep(0,7)
    trpars1[idparsopt] = trparsopt
@@ -17,7 +17,7 @@ dd_KI_loglik_choosepar = function(trparsopt,trparsfix,idparsopt,idparsfix,idpars
    {
       loglik = -Inf
    } else {
-      loglik = dd_KI_loglik(pars1,pars2,brtsM,brtsS,missnumspec)
+      loglik = dd_KI_loglik(pars1 = pars1,pars2 = pars2,brtsM = brtsM,brtsS = brtsS,missnumspec = missnumspec,methode = methode)
       if(is.nan(loglik) || is.na(loglik))
       {
          cat("There are parameter values used which cause numerical problems.\n")
